#include <stdio.h>

// MISC. UTILITY FUNCTIONS

// Error handler for CUDA GPU calls. 
//   Returns error number, filename and line number containing the error to the terminal.
//   Please refer to CUDA_Toolkit_Reference_Manual.pdf, section 4.23.3.3 enum cudaError
//   for error discription. Error enumeration starts from 0.
void checkForCudaErrors(const char* checkpoint_description)
{
    cudaError_t err = cudaGetLastError();
    if (err != cudaSuccess) {
        fprintf(stderr, "CUDA error detected at: %s\n"
                "System error string: %s\n", checkpoint_description,
                cudaGetErrorString(err));
        exit(EXIT_FAILURE);
    }
}

void checkForCudaErrors(const char* checkpoint_description, int iteration)
{
    cudaError_t err = cudaGetLastError();
    if (err != cudaSuccess) {
        fprintf(stderr, "CUDA error detected at: %s at iteration %d.\n"
                "System error string: %s\n", checkpoint_description, iteration,
                cudaGetErrorString(err));
        exit(EXIT_FAILURE);
    }
}

//Round a / b to nearest higher integer value
unsigned int iDivUp(unsigned int a, unsigned int b)
{
    return (a % b != 0) ? (a / b + 1) : (a / b);
}

// vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
